Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(18)

Unified Diff: chrome/browser/sync/glue/frontend_data_type_controller.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/frontend_data_type_controller.h
diff --git a/chrome/browser/sync/glue/frontend_data_type_controller.h b/chrome/browser/sync/glue/frontend_data_type_controller.h
index f55b59b68d2527ec0ca70701c46adea2aeb4aa09..4b34bbb22e248eb489003c21526a56ea82808d67 100644
--- a/chrome/browser/sync/glue/frontend_data_type_controller.h
+++ b/chrome/browser/sync/glue/frontend_data_type_controller.h
@@ -22,7 +22,7 @@ namespace base {
class TimeDelta;
}
-namespace csync {
+namespace syncer {
class SyncError;
}
@@ -39,7 +39,7 @@ class ChangeProcessor;
// syncable::ModelType type() const
// void CreateSyncComponents();
// NOTE: This class is deprecated! New sync datatypes should be using the
// csync::SyncableService API and the UIDataTypeController instead.
// TODO(zea): Delete this once all types are on the new API.
class FrontendDataTypeController : public DataTypeController {
public:
@@ -54,7 +54,7 @@ class FrontendDataTypeController : public DataTypeController {
virtual void StartAssociating(const StartCallback& start_callback) OVERRIDE;
virtual void Stop() OVERRIDE;
virtual syncable::ModelType type() const = 0;
- virtual csync::ModelSafeGroup model_safe_group() const OVERRIDE;
+ virtual syncer::ModelSafeGroup model_safe_group() const OVERRIDE;
virtual std::string name() const OVERRIDE;
virtual State state() const OVERRIDE;
@@ -89,7 +89,7 @@ class FrontendDataTypeController : public DataTypeController {
virtual void CleanUpState();
// Helper methods for cleaning up state an running the start callback.
- virtual void StartFailed(StartResult result, const csync::SyncError& error);
+ virtual void StartFailed(StartResult result, const syncer::SyncError& error);
virtual void FinishStart(StartResult result);
// Record association time.
« no previous file with comments | « chrome/browser/sync/glue/fake_generic_change_processor.cc ('k') | chrome/browser/sync/glue/frontend_data_type_controller.cc » ('j') | no next file with comments »
@@ -39,7 +39,7 @@ class ChangeProcessor;
// void CreateSyncComponents();
// NOTE: This class is deprecated! New sync datatypes should be using the
-// csync::SyncableService API and the UIDataTypeController instead.
+// syncer::SyncableService API and the UIDataTypeController instead.
// TODO(zea): Delete this once all types are on the new API.
class FrontendDataTypeController : public DataTypeController {

Powered by Google App Engine
This is Rietveld 408576698